@@ -308,6 +308,8 @@ static int32_t sigchld_handler(int32_t sig, void *data)
 						/* so add the final_score from the exit code of the terminated child process. 	*/
 						if (qb_loop_timer_is_running(storage_mon_poll_handle, expire_handle)) { 
 							if (WEXITSTATUS(status) !=0) {
+								syslog(LOG_ERR, "Error reading from device %s", devices[index]);
+
 								final_score += scores[index];
 
 								/* Update response values immediately in preparation for inquiries from clients. */
@@ -382,9 +384,11 @@ static int write_pid_file(const char *pidfile)
 		syslog(LOG_ERR, "Failed to write '%s' to %s: %s", pid, pidfile, strerror(errno));
 		goto done;
 	}
-	close(fd);
 	rc = 0;
 done:
+	if (fd != -1) {
+		close(fd);
+	}
 	if (pid != NULL) {
 		free(pid);
 	}
@@ -401,6 +405,8 @@ static void child_timeout_handler(void *data)
 	if (is_child_runnning()) {
 		for (i=0; i<device_count; i++) {
 			if (test_forks[i] > 0) {
+				syslog(LOG_ERR, "Reading from device %s did not complete in %d seconds timeout", devices[i], timeout);
+
 				/* If timeout occurs before SIGCHLD, add child process failure score to final_score. */
 				final_score += scores[i];
 
@@ -653,6 +659,7 @@ storage_mon_client(void)
 	int32_t rc;
 
 
+	memset(&response, 0, sizeof(response));
 	snprintf(ipcs_name, SMON_MAX_IPCSNAME, "storage_mon_%s", attrname);
 	conn = qb_ipcc_connect(ipcs_name, 0);
 	if (conn == NULL) {
@@ -663,6 +670,7 @@ storage_mon_client(void)
 	snprintf(request.message, SMON_MAX_MSGSIZE, "%s", SMON_GET_RESULT_COMMAND);
 	request.hdr.id = 0;
 	request.hdr.size = sizeof(struct storage_mon_check_value_req);
+	response.hdr.id = 0;
 	rc = qb_ipcc_send(conn, &request, request.hdr.size);
 	if (rc < 0) {
 		syslog(LOG_ERR, "qb_ipcc_send error : %d\n", rc);
@@ -683,7 +691,11 @@ storage_mon_client(void)
 	/* greater than 0	: monitoring error. 		*/
 	/* -1			: communication system error.	*/
 	/* -2                   : Not all checks completed for first device in daemon mode. */ 
-	rc = atoi(response.message);
+	if (strnlen(response.message, 1)) {
+		rc = atoi(response.message);
+	} else {
+		rc = -1;
+	}
 
 	syslog(LOG_DEBUG, "daemon response[%d]: %s \n", response.hdr.id, response.message);
 
